@@ -1,22 +1,22 @@
 "predict.vec2var" <-
-function(x, ..., n.ahead = 10, ci = 0.95, dumvar = NULL){
+function(object, ..., n.ahead = 10, ci = 0.95, dumvar = NULL){
   n.ahead <- as.integer(n.ahead)
-  K <- x$K
-  p <- x$p
-  obs <- x$obs
-  data.all <- x$datamat
-  ynames <- colnames(x$y)
-  Z <- x$datamat[, -c(1 : K)]
-  B <- x$deterministic
-  for(i in 1:x$p){
-    B <- cbind(B, x$A[[i]])
+  K <- object$K
+  p <- object$p
+  obs <- object$obs
+  data.all <- object$datamat
+  ynames <- colnames(object$y)
+  Z <- object$datamat[, -c(1 : K)]
+  B <- object$deterministic
+  for(i in 1:object$p){
+    B <- cbind(B, object$A[[i]])
   }
   ## Deterministic and lagged y's
   ## Retrieval of A in matrix (whole)
   Zdet <- matrix(rep(1, n.ahead), nrow = n.ahead, ncol = 1)
   rownames(Zdet) <- seq(nrow(data.all) + 1, length = n.ahead)
-  if(!is.null(eval(x$vecm@season))){
-    season <- eval(x$vecm@season)
+  if(!is.null(eval(object$vecm@season))){
+    season <- eval(object$vecm@season)
     seas.names <- paste("sd", 1:(season-1), sep = "")
     cycle <- tail(data.all[, seas.names], season)
     seasonal <- matrix(cycle, nrow = season, ncol = season - 1)
@@ -31,7 +31,7 @@ function(x, ..., n.ahead = 10, ci = 0.95, dumvar = NULL){
     rownames(seasonal) <- seq(nrow(data.all) + 1, length = n.ahead)
     Zdet <- cbind(Zdet, seasonal)
   }
-  if(!is.null(eval(x$vecm@dumvar))){
+  if(!is.null(eval(object$vecm@dumvar))){
     if(is.null(dumvar)){
       stop(paste("\nPlease, provide a matrix x for argument 'dumvar' with", n.ahead, "rows.\n", sep = " "))
     }
@@ -40,14 +40,14 @@ function(x, ..., n.ahead = 10, ci = 0.95, dumvar = NULL){
     }
     testsum <- sum((colnames(dumvar) %in% colnames(B)))
     if(!(testsum == ncol(dumvar))){
-      stop("\nColumn names of 'dumvar' do not match with column names in 'x$datamat'.\n")
+      stop("\nColumn names of 'dumvar' do not match with column names in 'object$datamat'.\n")
     }
     Zdet <- cbind(Zdet, dumvar)
   }
-  exogen.cols <- which(colnames(data.all) %in% colnames(x$deterministic))
+  exogen.cols <- which(colnames(data.all) %in% colnames(object$deterministic))
   Zy <- data.all[, -exogen.cols] 
   yse <- matrix(NA, nrow = n.ahead, ncol = K)
-  sig.y <- .fecovvec2var(x = x, n.ahead = n.ahead)
+  sig.y <- .fecovvec2var(x = object, n.ahead = n.ahead)
   for(i in 1 : n.ahead){
     yse[i, ] <- sqrt(diag(sig.y[, , i]))
   }
@@ -74,7 +74,7 @@ function(x, ..., n.ahead = 10, ci = 0.95, dumvar = NULL){
     colnames(forecasts[[i]]) <- c("fcst", "lower", "upper", "CI")
   }
   names(forecasts) <- ynames
-  result <- list(fcst = forecasts, endog = x$y, model = x) 
+  result <- list(fcst = forecasts, endog = object$y, model = object) 
   class(result) <- "varprd"
   return(result)
 }
